export declare enum Environment {
    Production = "production",
    Sandbox = "sandbox"
}
export interface HistoryResponse {
    appAppleId: string;
    bundleId: string;
    environment: Environment;
    hasMore: boolean;
    revision: string;
    signedTransactions: JWSTransaction[];
}
export declare type JWSTransaction = string;
export interface JWSDecodedHeader {
    alg: string;
    kid: string;
    x5c: string[];
}
export interface JWSTransactionDecodedPayload {
    appAccountToken?: string;
    bundleId: string;
    expiresDate?: number;
    inAppOwnershipType: OwnershipType;
    isUpgraded?: boolean;
    offerIdentifier?: string;
    offerType?: OfferType;
    originalPurchaseDate: number;
    originalTransactionId: string;
    productId: string;
    purchaseDate: number;
    quantity: number;
    revocationDate?: number;
    revocationReason?: number;
    signedDate: number;
    subscriptionGroupIdentifier?: string;
    transactionId: string;
    type: TransactionType;
    webOrderLineItemId: string;
}
export declare enum OwnershipType {
    Purchased = "PURCHASED",
    FamilyShared = "FAMILY_SHARED"
}
export declare enum TransactionType {
    AutoRenewableSubscription = "Auto-Renewable Subscription",
    NonConsumable = "Non-Consumable",
    Consumable = "Consumable",
    NonRenewingSubscription = "Non-Renewing Subscription"
}
export interface StatusResponse {
    data: SubscriptionGroupIdentifierItem[];
    environment: Environment;
    appAppleId: string;
    bundleId: string;
}
export interface SubscriptionGroupIdentifierItem {
    subscriptionGroupIdentifier: string;
    lastTransactions: LastTransactionsItem[];
}
export interface LastTransactionsItem {
    originalTransactionId: string;
    status: SubscriptionStatus;
    signedRenewalInfo: JWSRenewalInfo;
    signedTransactionInfo: JWSTransaction;
}
export declare type JWSRenewalInfo = string;
export declare enum SubscriptionStatus {
    Active = 1,
    Expired = 2,
    InBillingRetry = 3,
    InBillingGracePeriod = 4,
    Revoked = 5
}
export interface JWSRenewalInfoDecodedPayload {
    autoRenewProductId: string;
    autoRenewStatus: AutoRenewStatus;
    expirationIntent?: ExpirationIntent;
    gracePeriodExpiresDate?: number;
    isInBillingRetryPeriod?: boolean;
    offerIdentifier?: string;
    offerType?: OfferType;
    originalTransactionId: string;
    priceIncreaseStatus?: PriceIncreaseStatus;
    productId: string;
    signedDate: number;
}
export declare enum AutoRenewStatus {
    Off = 0,
    On = 1
}
export declare enum ExpirationIntent {
    Canceled = 1,
    BillingError = 2,
    RejectedPriceIncrease = 3,
    ProductUnavailable = 4
}
export declare enum OfferType {
    Introductory = 1,
    Promotional = 2,
    SubscriptionOfferCode = 3
}
export declare enum PriceIncreaseStatus {
    NoResponse = 0,
    Consented = 1
}
export interface OrderLookupResponse {
    orderLookupStatus: OrderLookupStatus;
    signedTransactions: JWSTransaction[];
}
export declare enum OrderLookupStatus {
    Valid = 0,
    Invalid = 1
}
